using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;

namespace assignment2.Controllers
{
    [Route("[controller]")]
    [ApiController]
    public class ProviderController : ControllerBase
    {
        private readonly IProviderService providerService;

        public ProviderController(IProviderService providerService)
        {
            this.providerService = providerService;
        }

        [HttpGet(Name = "ProvidersGet")]
        [Authorize(Roles = "Admin, Manager")]
        // Returnerer alle providers – kun ledere/admins må se forretningsoplysninger (Query 1)
        public async Task<IActionResult> Get()
        {
            var result = await providerService.GetProviders();
            if (result == null) return NotFound();
            return Ok(result);
        }

        [HttpGet("{id}", Name = "ProviderGet")]
        [Authorize(Roles = "Admin, Manager")]
        // Returnerer én provider baseret på ID – også begrænset til ledelse (Query 1)
        public async Task<IActionResult> Get(int id)
        {
            var result = await providerService.GetProvider(id);
            if (result == null) return NotFound();
            return Ok(result);
        }
    }
}
