﻿using assignment1.Interfaces;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;

namespace assignment1.Controllers
{
    [Route("[controller]")]
    [ApiController]
    public class SharedExperienceController : ControllerBase
    {
        private readonly ISharedExperienceService _sharedExperienceService;

        public SharedExperienceController(ISharedExperienceService experienceService)
        {
            _sharedExperienceService = experienceService;
        }

        [HttpGet]
        [AllowAnonymous]
        // Returnerer alle shared experiences + dato – må ses af alle (Query 3)
        public async Task<IActionResult> Get()
        {
            return Ok(await _sharedExperienceService.GetAll());
        }

        [HttpGet("guests/{id}")]
        [Authorize(Roles = "Admin, Manager")]
        // Returnerer gæster til én shared experience – kun synligt for ledere/admins (Query 4)
        public async Task<IActionResult> GetGuests(int id)
        {
            return Ok(await _sharedExperienceService.GetGuests(id));
        }

        [HttpGet("experiences/{id}")]
        [AllowAnonymous]
        // Returnerer experiences i en shared experience – offentligt (Query 5)
        public async Task<IActionResult> ExperiencesGet(int id)
        {
            return Ok(await _sharedExperienceService.GetExperiences(id));
        }

        [HttpGet("guestsInExperience/{id}/{experienceId}")]
        [Authorize(Roles = "Admin, Manager")]
        // Returnerer gæster i en specifik experience i en shared experience – kun ledelse (Query 6)
        public async Task<IActionResult> GuestsInExperienceGet(int id, int experienceId)
        {
            return Ok(await _sharedExperienceService.GetGuestsInExperience(id, experienceId));
        }
    }
}

