using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using assignment2.Interfaces;
using assignment2.Models;
using Microsoft.Extensions.Options;
using MongoDB.Bson;
using MongoDB.Bson.Serialization;
using MongoDB.Driver;

namespace assignment2.Services
{
    public class LogsService : ILogService
    {
        private readonly IMongoCollection<LogEntry> _logsCollection;
        private readonly MongoClient _mongoClient;
        private readonly IMongoDatabase _database;


        public LogsService(IOptions<LogsDatabaseSettings> logsDatabaseSettings)
        {
            _mongoClient = new MongoClient(
                logsDatabaseSettings.Value.ConnectionString);

            _database = _mongoClient.GetDatabase(
                logsDatabaseSettings.Value.DatabaseName);

            BsonClassMap.RegisterClassMap<LogEntry>(cm =>
            {
                cm.AutoMap();
                cm.SetIgnoreExtraElements(true);
            });

            _logsCollection = _database.GetCollection<LogEntry>(
                logsDatabaseSettings.Value.LogsCollectionName);
        }


        public async Task<IEnumerable<LogEntry>> GetAsync(string? user, string? operation, DateTime? startDate, DateTime? endTime, string? level)
        {

            var builder = Builders<LogEntry>.Filter;
            var filters = new List<FilterDefinition<LogEntry>>();

            if (!string.IsNullOrEmpty(user))
            {
                filters.Add(builder.Eq(u => u.Properties.LogInfo.User, user));
                Console.WriteLine($"Filtering by user: {user}");
            }

            if (!string.IsNullOrEmpty(operation))
            {
                filters.Add(builder.Eq(u => u.Properties.LogInfo.Operation, operation));
                Console.WriteLine($"Filtering by operation: {operation}");
            }

            if (startDate.HasValue && endTime.HasValue)
            {
                filters.Add(builder.And(builder.Gte(u => u.Properties.LogInfo.Timestamp, startDate), builder.Lte(u => u.Properties.LogInfo.Timestamp, endTime)));
                Console.WriteLine($"Filtering by date range: {startDate} to {endTime}");
            }
            if (!string.IsNullOrEmpty(level))
            {
                filters.Add(builder.Eq(u => u.Level, level));
                Console.WriteLine($"Filtering by level: {level}");
            }

            var filter = filters.Count > 0 ? builder.And(filters) : builder.Empty;

            var logs = await _logsCollection.Find(filter).ToListAsync();
            Console.WriteLine($"Number of logs found: {logs.Count}");

            return logs;
        }
    }
}