namespace assignment2.Services;

using assignment2.Models;
using Microsoft.EntityFrameworkCore;
using ZiggyCreatures.Caching.Fusion;

public class ProviderService : IProviderService
{
    private readonly ExperienceDBContext context;
    private readonly IFusionCache cache;

    public ProviderService(ExperienceDBContext context, IFusionCache cache)
    {
        this.context = context;
        this.cache = cache;
    }

    public async Task<IEnumerable<ProviderView>> GetProviders()
    {
        return await context.Providers
            .Select(p => new ProviderView
            {
                Address = p.Address,
                Phone = p.Phone,
                Permitpdf = p.Permitpdf,
                //CVR = p.CVR
            })
            .ToListAsync();
    }

    public async Task<Provider?> GetProvider(int id)
    {
        string cacheKey = $"provider:{id}";

        return await cache.GetOrSetAsync<Provider?>(
            cacheKey,
            _ =>
            {
                Thread.Sleep(2000);
                return context.Providers.FirstOrDefaultAsync(p => p.ProviderId == id);
            },
            TimeSpan.FromSeconds(30)
        );
    }
}
